"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const plugin_1 = require("../../plugin");
const theme_docusaurus_1 = require("../theme.docusaurus");
const theme_vuepress_1 = require("../theme.vuepress");
function metadata() {
    if (!isVisible()) {
        return '';
    }
    const md = `---
id: ${getId(this)}
title: ${getTitle(this)}
sidebar_label: ${getLabel(this)}
---\n`;
    return md;
}
exports.metadata = metadata;
function escapeYAMLStringIfNecessary(str = '') {
    return str.charAt(0) === '@'
        ? `'${str.replace(/([^\\])'/g, '$1\\\'')}'`
        : str;
}
function getId(page) {
    const urlSplit = page.url.split('/');
    return escapeYAMLStringIfNecessary(urlSplit[urlSplit.length - 1].replace('.md', ''));
}
function getLabel(page) {
    let label;
    if (page.url === plugin_1.MarkdownPlugin.theme.indexName) {
        label = plugin_1.MarkdownPlugin.settings.readme === 'none' ? 'Globals' : 'README';
    }
    else if (page.url === plugin_1.MarkdownPlugin.theme.globalsName) {
        label = 'Globals';
    }
    else {
        label = getTitle(page);
    }
    return escapeYAMLStringIfNecessary(label);
}
function getTitle(page) {
    let title;
    if (page.url === plugin_1.MarkdownPlugin.theme.indexName) {
        title = (page.project.packageInfo && page.project.packageInfo.label) || page.project.name;
    }
    else if (page.url === plugin_1.MarkdownPlugin.theme.globalsName) {
        title = 'Globals';
    }
    else {
        title = plugin_1.MarkdownPlugin.theme.navigationTitlesMap[page.url];
    }
    return escapeYAMLStringIfNecessary(title);
}
function isVisible() {
    if (plugin_1.MarkdownPlugin.theme instanceof theme_docusaurus_1.DocusaurusTheme || plugin_1.MarkdownPlugin.theme instanceof theme_vuepress_1.VuePressTheme) {
        return true;
    }
    return false;
}
